@@ -14,3 +14,19 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with lazr.batchnavigator. If not, see <http://www.gnu.org/licenses/>.
 "The lazr.batchnavigator tests."
+
+import unittest
+
+from lazr.batchnavigator.tests import (
+    test_docs,
+    )
+
+def test_suite():
+    # Discovery would be nice, but needs python2.7 for use with subunit &
+    # testrepository.
+    result = unittest.TestSuite()
+    result.addTests(test_docs.additional_tests())
+    modules = ['batchnavigator', 'z3batching']
+    result.addTests(unittest.TestLoader().loadTestsFromNames([
+        'lazr.batchnavigator.tests.test_' + name for name in modules]))
+    return result
